@@ -2,13 +2,13 @@ use strict;
 use warnings;
 
 package MooseX::Method::Signatures;
-# git description: v0.43-20-gca043b4
+{
+  $MooseX::Method::Signatures::VERSION = '0.47';
+}
+# git description: v0.46-8-ga38401b
 
 BEGIN {
-  $MooseX::Method::Signatures::AUTHORITY = 'cpan:FLORA';
-}
-{
-  $MooseX::Method::Signatures::VERSION = '0.44';
+  $MooseX::Method::Signatures::AUTHORITY = 'cpan:ETHER';
 }
 # ABSTRACT: Method declarations with type constraints and no source filter
 
@@ -22,6 +22,8 @@ use Text::Balanced qw/extract_quotelike/;
 use MooseX::Method::Signatures::Meta::Method;
 use MooseX::Method::Signatures::Types qw/PrototypeInjections/;
 use Sub::Name;
+use Moose::Util 'find_meta';
+use Module::Runtime 'use_module';
 use Carp;
 
 use aliased 'Devel::Declare::Context::Simple', 'ContextSimple';
@@ -168,7 +170,7 @@ sub strip_traits {
     for my $t (@traits) {
         next if $t->[0] =~ /::/;
         my $class = $ctx->get_curstash_name;
-        my $meta = Class::MOP::class_of($class) || Moose::Meta::Class->initialize($class);
+        my $meta = find_meta($class) || Moose::Meta::Class->initialize($class);
         my $func = $meta->get_package_symbol('&' . $t->[0]);
         next unless $func;
 
@@ -243,7 +245,7 @@ sub _parser {
     if ($args{traits}) {
         my @traits = ();
         foreach my $t (@{$args{traits}}) {
-            Class::MOP::load_class($t->[0]);
+            use_module($t->[0]);
             if ($t->[1]) {
                 %args = (%args, eval $t->[1]);
             };
@@ -355,12 +357,22 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
+
+=for :stopwords Florian Ragwitz Ash Rolsky Hakim Cassimally Jesse Luehrs Jonathan Rockway
+Scott Duff Justin Berlin Hunter Karen Etheridge Kent Fredric Lukas Mai Maik
+Hentsche Matt Cory Kraai Nicholas Perez Rhesa Rozendaal Ricardo SIGNES
+Sebastian Willert Steffen Watson Schwigon Yanick Champoux Dagfinn Ilmari
+Mannsåker Daniel Ruoso Dave Invocant sigil
 
 =head1 NAME
 
 MooseX::Method::Signatures - Method declarations with type constraints and no source filter
 
+=head1 VERSION
+
+version 0.47
+
 =head1 SYNOPSIS
 
     package Foo;
@@ -458,7 +470,7 @@ constraint.
 
     method foo ($bar, $, $baz)
 
-Sometimes you don't care about some params you're being called with. Just put
+Sometimes you don't care about some parameters you're being called with. Just put
 the bare sigil instead of a full variable name into the signature to avoid an
 extra lexical variable to be created.
 
@@ -607,6 +619,10 @@ make sure that your C<with> declaration happens after any
 method/subroutine declarations that may have the same name as a
 method/subroutine within a role.
 
+=head1 CAVEATS
+
+You are encouraged to read the L<MooseX::Declare/WARNING>.
+
 =head1 SEE ALSO
 
 L<MooseX::Declare>
@@ -623,14 +639,21 @@ L<Moose>
 
 L<signatures>
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
+=head1 AUTHOR
 
 Florian Ragwitz <rafl@debian.org>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Florian Ragwitz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 CONTRIBUTORS
+
+=over 4
+
 =item *
 
 Ash Berlin <ash@cpan.org>
@@ -641,6 +664,10 @@ Cory Watson <gphat@cpan.org>
 
 =item *
 
+Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
+
+=item *
+
 Daniel Ruoso <daniel@ruoso.com>
 
 =item *
@@ -649,7 +676,15 @@ Dave Rolsky <autarch@urth.org>
 
 =item *
 
-Hakim Cassimally <hakim.cassimally@gmail.com>
+Hakim Cassimally <osfameron@cpan.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Jonathan Rockway <jon@jrock.us>
 
 =item *
 
@@ -661,10 +696,18 @@ Justin Hunter <justin.d.hunter@gmail.com>
 
 =item *
 
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
 Kent Fredric <kentfredric@gmail.com>
 
 =item *
 
+Lukas Mai <l.mai@web.de>
+
+=item *
+
 Maik Hentsche <maik.hentsche@amd.com>
 
 =item *
@@ -673,6 +716,10 @@ Matt Kraai <kraai@ftbfs.org>
 
 =item *
 
+Nicholas Perez <nperez@cpan.org>
+
+=item *
+
 Rhesa Rozendaal <rhesa@cpan.org>
 
 =item *
@@ -681,27 +728,16 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =item *
 
+Sebastian Willert <willert@cpan.org>
+
+=item *
+
 Steffen Schwigon <ss5@renormalist.net>
 
 =item *
 
 Yanick Champoux <yanick@babyl.dyndns.org>
 
-=item *
-
-Nicholas Perez <nperez@cpan.org>
-
-=item *
-
-Karen Etheridge <ether@cpan.org>
-
 =back
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 by Florian Ragwitz.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
